Coverage for /home/lkjos/projects/django-custom-admin-pages/test_proj/test_app/migrations/0001_initial.py: 100%

1# Generated by Django 3.2 on 2023-07-30 14:53

2

3 from django.db import migrations, models

4

5

6 class Migration(migrations.Migration):

7 initial = True

8

9 dependencies = []

10

11 operations = [

12 migrations.CreateModel(

13 name="SomeModel",

14 fields=[

15 (

16 "id",

17 models.BigAutoField(

18 auto_created=True,

19 primary_key=True,

20 serialize=False,

21 verbose_name="ID",

22 ),

23 ),

24 ("some_field", models.BooleanField(default=False)),

25 ],

26 ),

27 ]